import requests
from dcentrapi.Base import Base


class EventPolling(Base):

    def get_collection(self, collection_name):
        url = self.url + "event_polling/collection"
        data = {
            "collection_name": collection_name
        }
        response = requests.post(url, json=data, headers=self.headers)
        return response.json()

    def set_schema(self, contract_name, contract_version, abi):
        url = self.url + "event_polling/schema"
        data = {
            "contract_name": contract_name,
            "contract_version": contract_version,
            "abi": abi
        }
        response = requests.post(url, json=data, headers=self.headers)
        return response.json()

    def add_collection_contract(self, contract_address, schema_id, network_name, collection_name):
        url = self.url + "event_polling/collection_contract"
        data = {
            "contract_address": contract_address,
            "schema_id": schema_id,
            "network_name": network_name,
            "collection_name": collection_name
        }
        response = requests.post(url, json=data, headers=self.headers)
        return response.json()

    def get_schema(self, contract_name, contract_version):
        url = self.url + "event_polling/schema"
        data = {
            "contract_name": contract_name,
            "contract_version": contract_version
        }
        response = requests.get(url, params=data, headers=self.headers)
        return response.json()

    def get_events_sum_of_values_in_range(self, collection_name, contract_address, event_name, field_name, start_time, end_time):
        url = self.url + "event_polling/events_sum_of_values_in_range"
        data = {
            "collection_name": collection_name,
            "contract_address": contract_address,
            "event_name": event_name,
            "field_name": field_name,
            "start_time": start_time,
            "end_time": end_time
        }
        response = requests.get(url, params=data, headers=self.headers)
        return response.json()

    def get_collection_sum_of_values_in_range(self, collection_name, event_name, field_name, start_time, end_time):
        url = self.url + "event_polling/collection_sum_of_values_in_range"
        data = {
            "collection_name": collection_name,
            "event_name": event_name,
            "field_name": field_name,
            "start_time": start_time,
            "end_time": end_time
        }
        response = requests.get(url, params=data, headers=self.headers)
        return response.json()

    def get_collection_contracts_sum_of_values(self, collection_name, event_name, field_name, start_time, end_time):
        url = self.url + "event_polling/collection_contracts_sum_of_values"
        data = {
            "collection_name": collection_name,
            "event_name": event_name,
            "field_name": field_name,
            "start_time": start_time,
            "end_time": end_time,
            "api_key": self.key,
            "user_name": self.username
        }
        response = requests.get(url, params=data, headers=self.headers)
        return response.json()

    def get_collection_daily_nof_transactions(self, collection_name, start_time, end_time):
        url = self.url + "event_polling/collection_daily_nof_transactions"
        data = {
            "collection_name": collection_name,
            "start_time": start_time,
            "end_time": end_time
        }
        response = requests.get(url, params=data, headers=self.headers)
        return response.json()

    def get_collection_nof_transactions(self, collection_name):
        url = self.url + "event_polling/collection_nof_transactions"
        data = {
            "collection_name": collection_name
        }
        response = requests.get(url, params=data, headers=self.headers)
        return response.json()

    def get_collection_nof_transactions_by_time(self, collection_name, start_time, end_time):
        url = self.url + "event_polling/collection_nof_transactions_by_time"
        data = {
            "collection_name": collection_name,
            "start_time": start_time,
            "end_time": end_time
        }
        response = requests.get(url, params=data, headers=self.headers)
        return response.json()

    def get_collection_nof_users_in_time_range(self, collection_name, start_time, end_time):
        url = self.url + "event_polling/collection_nof_users_in_time_range"
        data = {
            "collection_name": collection_name,
            "start_time": start_time,
            "end_time": end_time
        }
        response = requests.get(url, params=data, headers=self.headers)
        return response.json()

    def get_contract_nof_transactions(self, collection_name, contract_address):
        url = self.url + "event_polling/contract_nof_transactions"
        data = {
            "collection_name": collection_name,
            "contract_address": contract_address
        }
        response = requests.get(url, params=data, headers=self.headers)
        return response.json()

    def get_collection_users_in_time_range(self, collection_name, start_time, end_time):
        url = self.url + "event_polling/collection_users_in_time_range"
        data = {
            "collection_name": collection_name,
            "start_time": start_time,
            "end_time": end_time
        }
        response = requests.get(url, params=data, headers=self.headers)
        return response.json()

    def get_contract_users_in_time_range(self, collection_name, contract_address, start_time, end_time):
        url = self.url + "event_polling/contract_users_in_time_range"
        data = {
            "collection_name": collection_name,
            "contract_address": contract_address,
            "start_time": start_time,
            "end_time": end_time
        }
        response = requests.get(url, params=data, headers=self.headers)
        return response.json()

    def get_contracts_events_info(self, collection_name, contract_addresses, user_web3_addresses, event_names):
        url = self.url + "event_polling/contracts_events_info"
        data = {
            "collection_name": collection_name,
            "contract_addresses": contract_addresses,
            "user_web3_addresses": user_web3_addresses,
            "event_names": event_names
        }
        response = requests.get(url, params=data, headers=self.headers)
        return response.json()

    def get_nof_contracts_events_unique_transactions(self, collection_name, contract_addresses, event_names):
        url = self.url + "event_polling/contracts_events_info"
        data = {
            "collection_name": collection_name,
            "contract_addresses": contract_addresses,
            "event_names": event_names
        }
        response = requests.get(url, params=data, headers=self.headers)
        return response.json()

    def get_nof_token_transfers(self, contract_addresses):
        url = self.url + "event_polling/token_transfers"
        data = {
            "contract_addresses": contract_addresses
        }
        response = requests.get(url, params=data, headers=self.headers)
        return response.json()



import requests

from dcentrapi.Base import Base

class RpcAggregation(Base):

    def get_token_balance(self, user, token, network, rpc_url=None):
        url = self.url + "tokenBalance"
        data = {
            "network": network,
            "user": user,
            "token": token,
            "rpc_url": rpc_url
        }
        response = requests.get(url, params=data, headers=self.headers)
        return response.json()

    def get_token_balances_for_user(self, user, tokens : list, network, rpc_url=None):
        url = self.url + "tokenBalancesForUser"
        data = {
            "network": network,
            "user": user,
            "tokens": tokens,
            "rpc_url": rpc_url
        }
        response = requests.post(url, json=data, headers=self.headers)
        return response.json()
    
    def get_token_balance_for_users(self, users : list, token, network, rpc_url=None):
        url = self.url + "tokenBalanceForUsers"
        data = {
            "network": network,
            "users": users,
            "token": token,
            "rpc_url": rpc_url
        }
        response = requests.post(url, json=data, headers=self.headers)
        return response.json()

    def calculate_token_price_from_pair(self, pool, target_token_address, network, rpc_url=None):
        url = self.url + "calculateTokenPriceFromPair"
        data = {
            "network": network,
            "lp_token": pool,
            "target_token_address": target_token_address,
            "rpc_url": rpc_url
        }
        response = requests.get(url, params=data, headers=self.headers)
        return response.json()
    
    def calculate_reserves_amount_from_pair(self, pool, amount, network, rpc_url=None):
        url = self.url + "calculateReservesAmountsFromPair"
        data = {
            "network": network,
            "lp_token": pool,
            "amount": amount,
            "rpc_url": rpc_url
        }
        response = requests.get(url, params=data, headers=self.headers)
        return response.json()
    
    def get_reserves_from_pair(self, pool, network, rpc_url=None):
        url = self.url + "getReservesFromPair"
        data = {
            "network": network,
            "lp_token": pool,
            "rpc_url": rpc_url
        }
        response = requests.get(url, params=data, headers=self.headers)
        return response.json()








from dcentrapi.Base import Base
from dcentrapi.eventPolling import EventPolling
from dcentrapi.rpcAggregation import RpcAggregation
from dcentrapi.gasMonitor import GasMonitor
# from dcentrapi.merkleTree import MerkleTree, MerkleTreeNode



from pathlib import Path
from setuptools import setup, find_packages
import re

from dcentrapi.common import get_dapi_version


def get_property(prop, project):
    result = re.search(r'{}\s*=\s*[\'"]([^\'"]*)[\'"]'.format(prop), open(project + '/__init__.py').read())
    return result.group(1)


DESCRIPTION = 'Dcentralab Pypi packages'
this_directory = Path(__file__).parent
LONG_DESCRIPTION = (this_directory / "README.md").read_text()
project_name = 'dcentrapi'
VERSION = get_dapi_version()


# Setting up
setup(
    name="dcentrapi",
    version=VERSION,
    author="Dcentralab (Niv Shitrit)",
    author_email="<niv@dcentralab.com>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=LONG_DESCRIPTION,
    license='MIT',
    packages=find_packages(),
    install_requires=['requests'],
    keywords=['python'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)
